@@ -1,10 +1,17 @@
 # -*- coding: UTF-8 -*-
 # name = 'expy'
 
+from cmath import log
 from logging import CRITICAL, DEBUG, ERROR, INFO, WARNING
 from threading import Thread, BoundedSemaphore as IthreadBoundedSemaphore
 
 def genQRCode(url, midImg):
+    """
+    url - 二维码对应网址。
+
+    img - 二维码中间图片文件路径。
+    """
+
     from PIL import Image
     from qrcode import QRCode
     from qrcode.constants import ERROR_CORRECT_H
@@ -40,13 +47,15 @@ def genQRCode(url, midImg):
     return qrimg
 
 
-def genLogger(name=__file__, path=None, lvl=DEBUG):
+def genLogger(name=__file__, path=None, lvl=DEBUG,file=''):
     """
     name - 日志器名称
 
-    path - 日志文件输出路径, 如果没有指定则不写文件日志,日志文件夹总是命名为Log，如果路径Log，自动追加Log文件夹
+    path - 日志文件输出路径, 如果没有指定则不写文件日志，日志文件夹总是命名为Log，如果路径末尾不含Log/，自动追加Log文件夹。
 
     lvl  - 日志级别，默认DEBUG
+
+    file - 日志文件名称，如果没有给定，则以日期命名。
     """
     
     import logging, os
@@ -63,18 +72,21 @@ def genLogger(name=__file__, path=None, lvl=DEBUG):
     # 如果有路径则写文件日志
     if path:
         # 判断是否标准操作系统路径
-        assert os.path.isdir(path) == True
+        assert os.path.isdir(path) == True,'路径参数<path>不合法!'
         # 确保路径以分隔符结束
         if not path.endswith(os.sep):
             path = path + os.sep
-        # 确保路径以Log结束
+
+        # 确保路径以'Log/'结束
         if (path.split(os.sep)[-1].lower() != 'log'):
             path = path + 'Log' + os.sep
+
         # 判断并生成文件夹
         if not os.path.exists(path):
             os.makedirs(path)
         # 生成日志文件名称
-        logfile = path + strftime('%m-%d') + '.log'
+        logfile = path +(file or (strftime('%m-%d') + '.log'))
+
         # 关联日志到文件
         fh = logging.FileHandler(logfile, 'a', encoding='UTF-8')
         fh.setFormatter(logging.Formatter('%(asctime)s %(filename)12s :%(lineno)3d - %(levelname)5s: %(message)s'))
